@@ -15,6 +15,7 @@ PAYMENT_STATUS_CHOICES = (
         ('failed', _("failed")),
         )
 
+
 class PaymentManager(models.Manager):
     def get_query_set(self):
         return super(PaymentManager, self).get_query_set().select_related('order')
@@ -39,13 +40,12 @@ class PaymentFactory(models.Model, AbstractMixin):
         abstract = True
 
     def __unicode__(self):
-        return _("Payment #%(id)d") % { 'id' : self.id }
+        return _("Payment #%(id)d") % {'id': self.id}
 
     @classmethod
     def contribute(cls, order, **kwargs):
         return {'order': models.ForeignKey(order, **kwargs)}
 
-
     @classmethod
     def create(cls, order, backend):
         """
@@ -74,12 +74,14 @@ class PaymentFactory(models.Model, AbstractMixin):
         Always change payment status via this method. Otherwise the signal
         will not be emitted.
         """
-        old_status = self.status
-        self.status = new_status
-        self.save()
-        signals.payment_status_changed.send(
-            sender=type(self), instance=self,
-            old_status=old_status, new_status=new_status
+        if self.status != new_status:
+            # do anything only when status is really changed
+            old_status = self.status
+            self.status = new_status
+            self.save()
+            signals.payment_status_changed.send(
+                sender=type(self), instance=self,
+                old_status=old_status, new_status=new_status
             )
 
     def on_success(self, amount=None):
@@ -102,7 +104,6 @@ class PaymentFactory(models.Model, AbstractMixin):
             self.change_status('partially_paid')
         return fully_paid
 
-
     def on_failure(self):
         """
         Called when payment was failed
@@ -113,6 +114,7 @@ class PaymentFactory(models.Model, AbstractMixin):
 from django.db.models.loading import cache as app_cache, register_models
 #from utils import import_backend_modules
 
+
 def register_to_payment(order_class, **kwargs):
     """
     A function for registering unaware order class to ``getpaid``. This will
@@ -123,8 +125,10 @@ def register_to_payment(order_class, **kwargs):
     """
     global Payment
     global Order
+
     class Payment(PaymentFactory.construct(order=order_class, **kwargs)):
         objects = PaymentManager()
+
         class Meta:
             ordering = ('-created_on',)
             verbose_name = _("Payment")
@@ -138,5 +142,3 @@ def register_to_payment(order_class, **kwargs):
     for backend_name, models in backend_models_modules.items():
         app_cache.register_models(backend_name, *models.build_models(Payment))
     return Payment
-
-
