@@ -42,7 +42,6 @@ class TransferujBackendTestCase(TestCase):
                                                                                     None, None, None, None, None, None,
                                                                                     None))
 
-
         #Tests allowing all IP
         with self.settings(GETPAID_BACKENDS_SETTINGS={
             'getpaid.backends.transferuj': {'allowed_ip': [], 'key': ''},
@@ -91,7 +90,6 @@ class TransferujBackendTestCase(TestCase):
                                                                              None, None,
                                                                              '6a9e045010c27dfed24774b0afa37d0b'))
 
-
     def test_online_payment_ok(self):
         Payment = get_model('getpaid', 'Payment')
         order = Order(name='Test EUR order', total='123.45', currency='PLN')
@@ -151,115 +149,126 @@ class TransferujBackendTestCase(TestCase):
         self.assertEqual(payment.status, 'failed')
 
 
-
-
-
-
-
-
 def fake_payment_get_response_success(request):
     class fake_response:
         def read(self):
-            return """<?xml version="1.0" encoding="UTF-8"?>
-    <response>
-    <status>OK</status>
-    <trans>
-    <id>234748067</id>
-    <pos_id>123456789</pos_id>
-    <session_id>99:1342616247.41</session_id>
-    <order_id>99</order_id>
-    <amount>12345</amount>
-    <status>99</status>
-    <pay_type>t</pay_type>
-    <pay_gw_name>pt</pay_gw_name>
-    <desc>Test 2</desc>
-    <desc2></desc2>
-    <create>2012-07-18 14:57:28</create>
-    <init></init>
-    <sent></sent>
-    <recv></recv>
-    <cancel>2012-07-18 14:57:30</cancel>
-    <auth_fraud>0</auth_fraud>
-    <ts>1342616255805</ts>
-    <sig>4d4df5557b89a4e2d8c48436b1dd3fef</sig>	</trans>
-</response>"""
+            return """
+status:OK
+trans_id:234748067
+trans_pos_id:123456789
+trans_session_id:99:1342616247.41
+trans_order_id:99
+trans_amount:12345
+trans_status:99
+trans_pay_type:t
+trans_pay_gw_name:pt
+trans_desc:Test 2
+trans_desc2:
+trans_create:2012-07-18 14:57:28
+trans_init:
+trans_sent:
+trans_recv:
+trans_cancel:20trans_12-07-18 14:57:30
+trans_auth_fraud:0
+trans_ts:1342616255805
+trans_sig:4d4df5557b89a4e2d8c48436b1dd3fef
+"""
+
     return fake_response()
 
 
 def fake_payment_get_response_failure(request):
     class fake_response:
         def read(self):
-            return """<?xml version="1.0" encoding="UTF-8"?>
-    <response>
-    <status>OK</status>
-    <trans>
-    <id>234748067</id>
-    <pos_id>123456789</pos_id>
-    <session_id>98:1342616247.41</session_id>
-    <order_id>98</order_id>
-    <amount>12345</amount>
-    <status>2</status>
-    <pay_type>t</pay_type>
-    <pay_gw_name>pt</pay_gw_name>
-    <desc>Test 2</desc>
-    <desc2></desc2>
-    <create>2012-07-18 14:57:28</create>
-    <init></init>
-    <sent></sent>
-    <recv></recv>
-    <cancel>2012-07-18 14:57:30</cancel>
-    <auth_fraud>0</auth_fraud>
-    <ts>1342616255805</ts>
-    <sig>ee77e9515599e3fd2b3721dff50111dd</sig>	</trans>
-</response>"""
+            return """
+status:OK
+trans_id:234748067
+trans_pos_id:123456789
+trans_session_id:98:1342616247.41
+trans_order_id:98
+trans_amount:12345
+trans_status:2
+trans_pay_type:t
+trans_pay_gw_name:pt
+trans_desc:Test 2
+trans_desc2:
+trans_create:2012-07-18 14:57:28
+trans_init:
+trans_sent:
+trans_recv:
+trans_cancel:2012-07-18 14:57:30
+trans_auth_fraud:0
+trans_ts:1342616255805
+trans_sig:ee77e9515599e3fd2b3721dff50111dd
+"""
+
     return fake_response()
 
 
-
-
-
 class PayUBackendTestCase(TestCase):
     def setUp(self):
         self.client = Client()
 
+
+    def test_parse_text_result(self):
+        t1 = '''status:OK
+
+trans_id:349659572
+trans_pos_id:105664
+trans_session_id:48:1379695300.48
+trans_ts:1379695309225
+trans_sig:e4e981bfa780fa78fb077ca1f9295f2a
+
+        '''
+        self.assertEqual(getpaid.backends.payu.PaymentProcessor._parse_text_response(t1),
+                         {
+                             'status': 'OK',
+                             'trans_id': '349659572',
+                             'trans_pos_id': '105664',
+                             'trans_session_id': '48:1379695300.48',
+                             'trans_ts': '1379695309225',
+                             'trans_sig': 'e4e981bfa780fa78fb077ca1f9295f2a',
+                         }
+        )
+
     def test_online_malformed(self):
         response = self.client.post(reverse('getpaid-payu-online'), {})
         self.assertEqual(response.content, 'MALFORMED')
 
     def test_online_sig_err(self):
         response = self.client.post(reverse('getpaid-payu-online'), {
-            'pos_id' : 'wrong',
+            'pos_id': 'wrong',
             'session_id': '10:11111',
-            'ts' : '1111',
-            'sig' : 'wrong sig',
+            'ts': '1111',
+            'sig': 'wrong sig',
         })
         self.assertEqual(response.content, 'SIG ERR')
 
     def test_online_wrong_pos_id_err(self):
         response = self.client.post(reverse('getpaid-payu-online'), {
-            'pos_id' : '12345',
+            'pos_id': '12345',
             'session_id': '10:11111',
-            'ts' : '1111',
-            'sig' : '0d6129738c0aee9d4eb56f2a1db75ab4',
-            })
+            'ts': '1111',
+            'sig': '0d6129738c0aee9d4eb56f2a1db75ab4',
+        })
         self.assertEqual(response.content, 'POS_ID ERR')
 
     def test_online_wrong_session_id_err(self):
         response = self.client.post(reverse('getpaid-payu-online'), {
-            'pos_id' : '123456789',
+            'pos_id': '123456789',
             'session_id': '111111',
-            'ts' : '1111',
-            'sig' : 'fcf3db081d5085b45fe86ed0c6a9aa5e',
-            })
+            'ts': '1111',
+            'sig': 'fcf3db081d5085b45fe86ed0c6a9aa5e',
+        })
         self.assertEqual(response.content, 'SESSION_ID ERR')
 
     def test_online_ok(self):
         response = self.client.post(reverse('getpaid-payu-online'), {
-            'pos_id' : '123456789',
+            'pos_id': '123456789',
             'session_id': '1:11111',
-            'ts' : '1111',
-            'sig' : '2a78322c06522613cbd7447983570188',
-            })
+            'ts': '1111',
+            'sig': '2a78322c06522613cbd7447983570188',
+        })
         self.assertEqual(response.content, 'OK')
 
     @mock.patch("urllib2.urlopen", fake_payment_get_response_success)
@@ -267,9 +276,11 @@ class PayUBackendTestCase(TestCase):
         Payment = get_model('getpaid', 'Payment')
         order = Order(name='Test EUR order', total='123.45', currency='PLN')
         order.save()
-        payment = Payment(pk=99, order=order, amount=order.total, currency=order.currency, backend='getpaid.backends.payu')
+        payment = Payment(pk=99, order=order, amount=order.total, currency=order.currency,
+                          backend='getpaid.backends.payu')
         payment.save(force_insert=True)
-        payment = Payment.objects.get(pk=99) # this line is because django bug https://code.djangoproject.com/ticket/5903
+        payment = Payment.objects.get(
+            pk=99)  # this line is because django bug https://code.djangoproject.com/ticket/5903
         processor = getpaid.backends.payu.PaymentProcessor(payment)
         processor.get_payment_status('99:1342616247.41')
         self.assertEqual(payment.status, 'paid')
@@ -281,9 +292,11 @@ class PayUBackendTestCase(TestCase):
         Payment = get_model('getpaid', 'Payment')
         order = Order(name='Test EUR order', total='123.45', currency='PLN')
         order.save()
-        payment = Payment(pk=98, order=order, amount=order.total, currency=order.currency, backend='getpaid.backends.payu')
+        payment = Payment(pk=98, order=order, amount=order.total, currency=order.currency,
+                          backend='getpaid.backends.payu')
         payment.save(force_insert=True)
-        payment = Payment.objects.get(pk=98) # this line is because django bug https://code.djangoproject.com/ticket/5903
+        payment = Payment.objects.get(
+            pk=98)  # this line is because django bug https://code.djangoproject.com/ticket/5903
         processor = getpaid.backends.payu.PaymentProcessor(payment)
         processor.get_payment_status('98:1342616247.41')
         self.assertEqual(payment.status, 'failed')
@@ -291,12 +304,12 @@ class PayUBackendTestCase(TestCase):
         self.assertEqual(payment.amount_paid, Decimal('0'))
 
 
-
 def fake_przelewy24_payment_get_response_success(request):
     class fake_response:
         def read(self):
             return """RESULT
 TRUE"""
+
     return fake_response()
 
 
@@ -307,29 +320,30 @@ def fake_przelewy24_payment_get_response_failed(request):
 ERR
 123
 Some error description"""
+
     return fake_response()
 
-class Przelewy24PaymentProcessorTestCase(TestCase):
 
+class Przelewy24PaymentProcessorTestCase(TestCase):
     def test_sig(self):
         # Test based on p24 documentation
         sig = przelewy24.PaymentProcessor.compute_sig({
-            'key1' : '9999',
-            'key2' : '2500',
-            'key3' : 'ccc',
-            'key4' : 'abcdefghijk',
-            'crc' : 'a123b456c789d012',
+                                                          'key1': '9999',
+                                                          'key2': '2500',
+                                                          'key3': 'ccc',
+                                                          'key4': 'abcdefghijk',
+                                                          'crc': 'a123b456c789d012',
 
-        }, ('key4', 'key1', 'key2', 'crc'), 'a123b456c789d012')
+                                                      }, ('key4', 'key1', 'key2', 'crc'), 'a123b456c789d012')
         self.assertEqual(sig, 'e2c43dec9578633c518e1f514d3b434b')
 
-
     @mock.patch("urllib2.urlopen", fake_przelewy24_payment_get_response_success)
     def test_get_payment_status_success(self):
         Payment = get_model('getpaid', 'Payment')
         order = Order(name='Test PLN order', total='123.45', currency='PLN')
         order.save()
-        payment = Payment(pk=191, order=order, amount=order.total, currency=order.currency, backend='getpaid.backends.przelewy24')
+        payment = Payment(pk=191, order=order, amount=order.total, currency=order.currency,
+                          backend='getpaid.backends.przelewy24')
         payment.save(force_insert=True)
         payment = Payment.objects.get(pk=191)
         processor = getpaid.backends.przelewy24.PaymentProcessor(payment)
@@ -345,7 +359,8 @@ class Przelewy24PaymentProcessorTestCase(TestCase):
         order = Order(name='Test PLN order', total='123.45', currency='PLN')
         order.save()
 
-        payment = Payment(pk=192, order=order, amount=order.total, currency=order.currency, backend='getpaid.backends.przelewy24')
+        payment = Payment(pk=192, order=order, amount=order.total, currency=order.currency,
+                          backend='getpaid.backends.przelewy24')
         payment.save(force_insert=True)
         payment = Payment.objects.get(pk=192)
         processor = getpaid.backends.przelewy24.PaymentProcessor(payment)
@@ -355,14 +370,14 @@ class Przelewy24PaymentProcessorTestCase(TestCase):
         self.assertNotEqual(payment.paid_on, None)
         self.assertEqual(payment.amount_paid, Decimal('122.45'))
 
-
     @mock.patch("urllib2.urlopen", fake_przelewy24_payment_get_response_failed)
     def test_get_payment_status_failed(self):
         Payment = get_model('getpaid', 'Payment')
         order = Order(name='Test PLN order', total='123.45', currency='PLN')
         order.save()
 
-        payment = Payment(pk=192, order=order, amount=order.total, currency=order.currency, backend='getpaid.backends.przelewy24')
+        payment = Payment(pk=192, order=order, amount=order.total, currency=order.currency,
+                          backend='getpaid.backends.przelewy24')
         payment.save(force_insert=True)
         payment = Payment.objects.get(pk=192)
         processor = getpaid.backends.przelewy24.PaymentProcessor(payment)
